@@ -2,6 +2,7 @@
 import asyncio
 from concurrent import futures
 from functools import cached_property
+from typing import Optional
 
 import abstracts
 
@@ -22,12 +23,14 @@ class IReactive(metaclass=abstracts.Interface):
 
 
 class AReactive(IReactive, metaclass=abstracts.Abstraction):
-    _loop = None
-    _pool = None
+    _loop: Optional[asyncio.AbstractEventLoop] = None
+    _pool: Optional[futures.Executor] = None
 
     @cached_property
     def loop(self) -> asyncio.AbstractEventLoop:
-        return self._loop or asyncio.get_running_loop()
+        """Does not expect an existing loop to be running if it is not passed a
+        loop."""
+        return self._loop or asyncio.get_event_loop()
 
     @cached_property
     def pool(self) -> futures.Executor:
